@@ -1,5 +1,5 @@
 package Business::RO::TaxDeduction::Amount;
-$Business::RO::TaxDeduction::Amount::VERSION = '0.011';
+$Business::RO::TaxDeduction::Amount::VERSION = '0.012';
 # ABSTRACT: Personal deduction amount by year and number of persons
 
 use 5.010001;
@@ -9,20 +9,9 @@ use MooX::HandlesVia;
 use Business::RO::TaxDeduction::Types qw(
     Int
     HashRef
-    TaxPersons
 );
 with qw(Business::RO::TaxDeduction::Role::Utils);
 
-has 'persons' => (
-    is       => 'ro',
-    isa      => TaxPersons,
-    required => 1,
-    coerce   => sub {
-		$_[0] >= 4 ? 4 : $_[0];
-	},
-    default  => sub { 0 },
-);
-
 has '_deduction_map_2005' => (
     is          => 'ro',
     isa         => HashRef,
@@ -53,6 +42,21 @@ has '_deduction_map_2016' => (
     },
 );
 
+has '_deduction_map_2018' => (
+    is          => 'ro',
+    isa         => HashRef,
+    lazy        => 1,
+    default     => sub {
+        return {
+            0 => 510,
+            1 => 670,
+            2 => 830,
+            3 => 990,
+            4 => 1310,
+        };
+    },
+);
+
 has '_deduction_map' => (
     is          => 'ro',
     handles_via => 'Hash',
@@ -92,13 +96,13 @@ Business::RO::TaxDeduction::Amount - Personal deduction amount by year and numbe
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 SYNOPSIS
 
     my $ded = Business::RO::TaxDeduction::Amount->new(
         persons => 4,
-        year    => 2015,
+        year    => 2018,
     );
     say $ded->amount;
 
@@ -110,10 +114,6 @@ Data module.  Personal deduction amount by year and number of persons.
 
 =head2 ATTRIBUTES
 
-=head3 persons
-
-Number of persons.  Coerced to 4 if is greater than 4.
-
 =head3 _deduction_map_2005
 
 Uses the amounts described in the document:
@@ -134,6 +134,15 @@ contribuabilii care realizează venituri din salarii la funcţia de
 bază, începând cu luna ianuarie 2016, potrivit prevederilor art. 77
 alin. (2) şi ale art. 66 din Legea nr. 227/2015 privind Codul fiscal".
 
+=head3 _deduction_map_2018
+
+Uses the amounts described in the document:
+
+ORDONANȚĂ DE URGENȚĂ Nr. 79/2017 din 8 noiembrie 2017 pentru
+modificarea și completarea Legii nr. 227/2015 privind Codul fiscal
+EMITENT: GUVERNUL ROMÂNIEI PUBLICATĂ ÎN: MONITORUL OFICIAL NR. 885 din
+10 noiembrie 2017
+
 =head3 _deduction_map
 
 Choses the appropriate deduction map by year and returns the amount
@@ -151,7 +160,7 @@ Returns the C<amount> using the C<_deduction_map> method.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Ștefan Suciu.
+This software is copyright (c) 2018 by Ștefan Suciu.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
